You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pivot.apache.org by rw...@apache.org on 2017/12/15 21:31:40 UTC

svn commit: r1818345 - /pivot/trunk/wtk/src/org/apache/pivot/wtk/skin/RulerSkin.java

Author: rwhitcomb
Date: Fri Dec 15 21:31:40 2017
New Revision: 1818345

URL: http://svn.apache.org/viewvc?rev=1818345&view=rev
Log:
PIVOT-1017: Change the number font size to 11 -- 9.5 just looked too small.

Modified:
    pivot/trunk/wtk/src/org/apache/pivot/wtk/skin/RulerSkin.java

Modified: pivot/trunk/wtk/src/org/apache/pivot/wtk/skin/RulerSkin.java
URL: http://svn.apache.org/viewvc/pivot/trunk/wtk/src/org/apache/pivot/wtk/skin/RulerSkin.java?rev=1818345&r1=1818344&r2=1818345&view=diff
==============================================================================
--- pivot/trunk/wtk/src/org/apache/pivot/wtk/skin/RulerSkin.java (original)
+++ pivot/trunk/wtk/src/org/apache/pivot/wtk/skin/RulerSkin.java Fri Dec 15 21:31:40 2017
@@ -522,8 +522,8 @@ public class RulerSkin extends Component
     public void setFont(Font font) {
         Utils.checkNull(font, "font");
 
-        // The font we will use is the same name and style, but a 9.5 pt type
-        this.font = font.deriveFont(9.5f);
+        // The font we will use is the same name and style, but a 11 pt type
+        this.font = font.deriveFont(11.0f);
 
         // Make some size calculations for the drawing code
         FontRenderContext fontRenderContext = Platform.getFontRenderContext();